@@ -1,4 +1,4 @@
-# Copyright (C) 2009 - 2016  Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2009 - 2019  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -81,8 +81,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
     # Add Rcpp to the DESCRIPTION
     DESCRIPTION <- file.path(root, "DESCRIPTION")
     if (file.exists(DESCRIPTION)) {
-        imports <- c(if (isTRUE(module)) "methods",
-                     sprintf("Rcpp (>= %s)", packageDescription("Rcpp")[["Version"]]))
+        imports <- c(if (isTRUE(module)) "methods", sprintf("Rcpp (>= %s)", getRcppVersion()))
         x <- cbind(read.dcf(DESCRIPTION),
                    "Imports" = paste(imports, collapse = ", "),
                    "LinkingTo" = "Rcpp")
@@ -138,7 +137,6 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
             file.copy(file, src)
             message(" >> copied ", file, " to src directory" )
         }
-        compileAttributes(root)
     }
 
     if (example_code) {
@@ -146,10 +144,6 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
             file.copy(file.path( skeleton, "rcpp_hello_world_attributes.cpp"),
                       file.path( src, "rcpp_hello_world.cpp"))
             message(" >> added example src file using Rcpp attributes")
-            compileAttributes(root)
-            message(" >> compiled Rcpp attributes")
-            message(" >> do NOT modify by hand either RcppExports.cpp or ",
-                    "RcppExports.R")
         } else {
             header <- readLines(file.path(skeleton, "rcpp_hello_world.h"))
             header <- gsub("@PKG@", name, header, fixed = TRUE)
@@ -218,6 +212,11 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
         rm("rcpp_hello_world", envir = env)
     }
 
+    if (attributes) {
+        compileAttributes(root)
+        message(" >> compiled Rcpp attributes ")
+    }
+
     invisible(NULL)
 }
 
