@@ -24,110 +24,35 @@
 
 #define Rcpp_list1 Rf_list1
 #define Rcpp_lang1 Rf_lang1
+#define Rcpp_list2 Rf_list2
+#define Rcpp_lang2 Rf_lang2
+#define Rcpp_list3 Rf_list3
+#define Rcpp_lang3 Rf_lang3
+#define Rcpp_list4 Rf_list4
+#define Rcpp_lang4 Rf_lang4
+#define Rcpp_list5 Rf_list5
+#define Rcpp_lang5 Rf_lang5
+#define Rcpp_list6 Rf_list6
+#define Rcpp_lang6 Rf_lang6
+
+#define Rcpp_lcons Rf_lcons
 
 namespace Rcpp {
 
-inline SEXP Rcpp_lcons(SEXP car, SEXP cdr){
-    Shield<SEXP> out( Rf_lcons( car, cdr ) );
-    return out ;
-}
-
-inline SEXP Rcpp_list2( SEXP x0, SEXP x1 ){
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list1(x1)) );
-    return out;
-}
-
-inline SEXP Rcpp_lang2( SEXP x0, SEXP x1 ){
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list1(x1)) );
-    return out;
-}
-
-
-
-
-
-inline SEXP Rcpp_list3( SEXP x0, SEXP x1, SEXP x2 )
-{
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list2(x1, x2)) );
-    return out;
-}
-
-inline SEXP Rcpp_lang3( SEXP x0, SEXP x1, SEXP x2 )
-{
-    Shield<SEXP> out(Rf_lcons(x0, Rcpp_list2(x1, x2)) );
-    return out;
-}
-
-
-
-
-
-inline SEXP Rcpp_list4( SEXP x0, SEXP x1, SEXP x2, SEXP x3 )
-{
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list3(x1, x2, x3)) );
-
-    return out;
-}
-
-inline SEXP Rcpp_lang4( SEXP x0, SEXP x1, SEXP x2, SEXP x3 )
-{
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list3(x1, x2, x3)) );
-
-    return out;
-}
-
-
-
-
-
-inline SEXP Rcpp_list5( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4 )
-{
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list4(x1, x2, x3, x4)) );
-
-    return out;
-}
-
-inline SEXP Rcpp_lang5( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4 )
-{
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list4(x1, x2, x3, x4)) );
-
-    return out;
-}
-
-
-
-
-
-inline SEXP Rcpp_list6( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5 )
-{
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list5(x1, x2, x3, x4, x5)) );
-
-    return out;
-}
-
-inline SEXP Rcpp_lang6( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5 )
-{
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list5(x1, x2, x3, x4, x5)) );
-
-    return out;
-}
-
-
-
-
-
 inline SEXP Rcpp_list7( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list6(x1, x2, x3, x4, x5, x6)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list6(x1, x2, x3, x4, x5, x6));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang7( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list6(x1, x2, x3, x4, x5, x6)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list6(x1, x2, x3, x4, x5, x6));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -136,16 +61,18 @@ inline SEXP Rcpp_lang7( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SE
 
 inline SEXP Rcpp_list8( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list7(x1, x2, x3, x4, x5, x6, x7)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list7(x1, x2, x3, x4, x5, x6, x7));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang8( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list7(x1, x2, x3, x4, x5, x6, x7)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list7(x1, x2, x3, x4, x5, x6, x7));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -154,16 +81,18 @@ inline SEXP Rcpp_lang8( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SE
 
 inline SEXP Rcpp_list9( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list8(x1, x2, x3, x4, x5, x6, x7, x8)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list8(x1, x2, x3, x4, x5, x6, x7, x8));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang9( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list8(x1, x2, x3, x4, x5, x6, x7, x8)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list8(x1, x2, x3, x4, x5, x6, x7, x8));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -172,16 +101,18 @@ inline SEXP Rcpp_lang9( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SE
 
 inline SEXP Rcpp_list10( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list9(x1, x2, x3, x4, x5, x6, x7, x8, x9)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list9(x1, x2, x3, x4, x5, x6, x7, x8, x9));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang10( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list9(x1, x2, x3, x4, x5, x6, x7, x8, x9)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list9(x1, x2, x3, x4, x5, x6, x7, x8, x9));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -190,16 +121,18 @@ inline SEXP Rcpp_lang10( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list11( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list10(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list10(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang11( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list10(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list10(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -208,16 +141,18 @@ inline SEXP Rcpp_lang11( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list12( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list11(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list11(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang12( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list11(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list11(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -226,16 +161,18 @@ inline SEXP Rcpp_lang12( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list13( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list12(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list12(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang13( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list12(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list12(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -244,16 +181,18 @@ inline SEXP Rcpp_lang13( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list14( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list13(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list13(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang14( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list13(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list13(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -262,16 +201,18 @@ inline SEXP Rcpp_lang14( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list15( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list14(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list14(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang15( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list14(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list14(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -280,16 +221,18 @@ inline SEXP Rcpp_lang15( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list16( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list15(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list15(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang16( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list15(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list15(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -298,16 +241,18 @@ inline SEXP Rcpp_lang16( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list17( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15, SEXP x16 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list16(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list16(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang17( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15, SEXP x16 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list16(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list16(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -316,16 +261,18 @@ inline SEXP Rcpp_lang17( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list18( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15, SEXP x16, SEXP x17 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list17(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list17(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang18( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15, SEXP x16, SEXP x17 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list17(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list17(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -334,16 +281,18 @@ inline SEXP Rcpp_lang18( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list19( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15, SEXP x16, SEXP x17, SEXP x18 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list18(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17, x18)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list18(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17, x18));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang19( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15, SEXP x16, SEXP x17, SEXP x18 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list18(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17, x18)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list18(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17, x18));
+    UNPROTECT(1);
+    return x0;
 }
 
 
@@ -352,16 +301,18 @@ inline SEXP Rcpp_lang19( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, S
 
 inline SEXP Rcpp_list20( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15, SEXP x16, SEXP x17, SEXP x18, SEXP x19 )
 {
-    Shield<SEXP> out( Rf_cons(x0, Rcpp_list19(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17, x18, x19)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_cons(x0, Rcpp_list19(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17, x18, x19));
+    UNPROTECT(1);
+    return x0;
 }
 
 inline SEXP Rcpp_lang20( SEXP x0, SEXP x1, SEXP x2, SEXP x3, SEXP x4, SEXP x5, SEXP x6, SEXP x7, SEXP x8, SEXP x9, SEXP x10, SEXP x11, SEXP x12, SEXP x13, SEXP x14, SEXP x15, SEXP x16, SEXP x17, SEXP x18, SEXP x19 )
 {
-    Shield<SEXP> out( Rf_lcons(x0, Rcpp_list19(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17, x18, x19)) );
-
-    return out;
+    PROTECT(x0);
+    x0 = Rf_lcons(x0, Rcpp_list19(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10, x11, x12, x13, x14, x15, x16, x17, x18, x19));
+    UNPROTECT(1);
+    return x0;
 }
 
 }
